/*
 * Copyright 2020 Vlad Zahorodnii <vlad.zahorodnii@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) version 3, or any
 * later version accepted by the membership of KDE e.V. (or its
 * successor approved by the membership of KDE e.V.), which shall
 * act as a proxy defined in Section 6 of version 3 of the license.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef WINDOWSHADOW_H
#define WINDOWSHADOW_H

#include <KWayland/Client/buffer.h>
#include <KWayland/Client/shadow.h>
#include <KWindowSystem/private/kwindowshadow_p.h>

class WindowShadowTile final : public KWindowShadowTilePrivate
{
public:
    bool create() override;
    void destroy() override;

    static WindowShadowTile *get(const KWindowShadowTile *tile);

    KWayland::Client::Buffer::Ptr buffer;
};

class WindowShadow final : public QObject, public KWindowShadowPrivate
{
public:
    bool create() override;
    void destroy() override;

protected:
    bool eventFilter(QObject *watched, QEvent *event) override;

private:
    bool internalCreate();
    void internalDestroy();

    QPointer<KWayland::Client::Shadow> shadow;
};

#endif // WINDOWSHADOW_H
